#
# spec file for package python-polib
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-polib
Version:        1.0.6
Release:        5.2
Url:            http://bitbucket.org/izi/polib/
Summary:        A library to manipulate gettext files
License:        MIT
Group:          Development/Languages/Python
Source0:        https://pypi.python.org/packages/source/p/polib/polib-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-Sphinx
BuildRequires:  python-devel
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
polib allows you to manipulate, create, modify gettext catalogs (.pot, .po and
binary .mo files). You can load existing files, iterate through it's entries,
add, modify entries, comments or metadata, etc... or create new po/pot files
from scratch.

polib provides a simple and pythonic API, exporting only two convenience
functions 'pofile' and 'mofile', and the 4 core classes: POFile, MOFile,
POEntry and MOEntry for creating new files/entries.

%package doc
Summary:        A library to manipulate gettext files
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description doc
polib allows you to manipulate, create, modify gettext catalogs (.pot, .po and
binary .mo files). You can load existing files, iterate through it's entries,
add, modify entries, comments or metadata, etc... or create new po/pot files
from scratch.

polib provides a simple and pythonic API, exporting only two convenience
functions 'pofile' and 'mofile', and the 4 core classes: POFile, MOFile,
POEntry and MOEntry for creating new files/entries.

This package contains documentation in HTML format.

%prep
%setup -q -n polib-%{version}

%build
python setup.py build
pushd docs
make html
rm _build/html/.buildinfo
popd

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
./runtests.sh

%files
%defattr(-,root,root)
%doc LICENSE CHANGELOG README.rst
%{python_sitelib}/*

%files doc
%defattr(-,root,root)
%doc docs/_build/html

%changelog
* Mon May 11 2015 benoit.monin@gmx.fr
- update to version 1.0.6:
  * Wheel support
  * Add missing 'Language' and 'Plural-Forms' to metadata ordering
  * More accurate float operation for POFile.percent_translated()
- additional changes from version 1.0.5:
  * Fixed issue #59: tokens variable referenced before assignment
  * Implemented feature request #56: line number information in PO
    entries
  * Fixed issue #61: polib does not handle previous msgid on
    multines properly
- additional changes from version 1.0.4:
  * Fixed issue #43: improved check that determine if polib is
    dealing with a filepath or unicode content
  * Fixed issue #44: polib now checks MO files revision number and
    throws an error if the number is unexpected
  * Fixed issue #45: parse properly mo files with no header entry
  * Fixed issue #47: added flags attribute for MOEntry to be
    consistant with POEntry
  * Fixed issue #49: use integers rather than strings for
    msgstr_plural keys
  * Fixed issue #51: if a PO file ends with a comment, polib adds a
    spurious empty entry at the end
  * Fixed issue #52: bad magic number written on big endian
    platforms
  * Fixed issue #53: added a __hash__() method to POEntry and
    MOEntry classes
  * Fixed issue #54: use lowercase for state identifiers. This
    fixes issues with certain locales and string.lower()
  * Fixed issue #58: use io.open() instead of codecs.open() because
    the latter doesn't handle very well universal line endings
  * Make sure the mo file is closed at garbage collection, this
    prevents warnings on unclosed file when running tests with
    python >= 3.2
  * Better way to test indianness
  * polib download URL is now on Pypi
- drop endian_magic.patch: fixed upstream
- point the source URL to pypi
* Thu Sep 12 2013 dvaleev@suse.com
- Fixed issue #53 (bad magic number written on big endian platforms)
  endian_magic.patch
* Mon Feb 11 2013 lazy.kent@opensuse.org
- Correct RPM group.
- Use full URL as a source.
- Doesn't require fdupes.
* Sat Feb  9 2013 p.drouand@gmail.com
- Update to 1.0.3
  * Fixed issue #38: POFile.append() raised a duplicate exception when
    you tried to add a new entry with the same msgid and a different msgctxt
    (only when check_for_duplicates option is set to True)
  * Fixed issue #39: Added __init__.py file for convenience
  * Fixed issue #41: UnicodeDecodeError when running setup.py build on
    python3 with C locale
  * polib is now fully PEP8 compliant
  * Small improvements: remove unused "typ" var, mproved Makefile, Make sure
    BaseFile.__contains__ returns a boolean value
* Wed Sep 12 2012 os-dev@jacraig.com
- Update to 1.0.1:
  * speed up POFile.merge method
  * allow comments starting with two '#' characters
* Wed Jun 13 2012 os-dev@jacraig.com
- Update to 1.0.0:
  * polib.pofile and polib.mofile functions can now return a custom class
    (thanks Craig Blaszczyk)
  * polib now can find the metadata entry no matter where it is located (thanks
    François Poirotte)
  * fixed issue #28 (IOError on reading obsolete "previous msgid" entries)
    (thanks James Ni)
  * Dropped python 2.4 support
- Add %%check section to run unit tests
* Tue Jan 31 2012 saschpe@suse.de
- Resolved spec file conflict
- Remove obsolete SUSE version check (for 10.1)
* Tue Aug 16 2011 saschpe@suse.de
- Fix build on SLE_10 by adding a version check around fdupes and
  by removing the %%check section
* Mon Aug 15 2011 saschpe@suse.de
- Spec file cleanup:
  * Remove authors from description
  * Much simpler docs generation and installation (don't install
    Makefile and reStructuredText sources)
* Sun Aug 14 2011 hpj@urpla.net
- install docs in the package doc dir
* Sat Aug 13 2011 hpj@urpla.net
- Release 0.7.0
- create and package docs
* Mon Sep 20 2010 fcrozat@novell.com
- Release 0.5.3
